Module verify

Module verify 

Host-side verification helpers backed by bitcoin/secp256k1. Host-side verification utilities backed by bitcoin/secp256k1.

Structs

BitcoinTaprootOps
Taproot operations implemented with bitcoin/secp256k1 types.

Functions

group_pubkey_from_reveal
Derives the compressed group key bytes using the bitcoin backend.
verify_group_key_reveal
Verifies that the group key reveal derives the asset’s group key using the bitcoin backend.