Host-side verification helpers backed by bitcoin/secp256k1. Host-side verification utilities backed by bitcoin/secp256k1.
Structs
- Bitcoin
Taproot Ops - Taproot operations implemented with bitcoin/secp256k1 types.
Functions
- group_
pubkey_ from_ reveal - Derives the compressed group key bytes using the bitcoin backend.
- verify_
group_ key_ reveal - Verifies that the group key reveal derives the asset’s group key using the bitcoin backend.